@@ -15,13 +15,13 @@ class Monster(pygame.sprite.Sprite):
 	def __init__(self, centerPoint, level):
 		pygame.sprite.Sprite.__init__(self)
 
-		self._normal__image = level.sprites[level.MONSTER]
-		self._scared__image = level.sprites[level.SCARED_MONSTER]
-		if self._scared__image is None:
-			self._scared__image = self._normal__image
-		self._evil__image = level.sprites[level.EVIL_MONSTER]
+		self._normal_image = level.sprites[level.MONSTER]
+		self._scared_image = level.sprites[level.SCARED_MONSTER]
+		if self._scared_image is None:
+			self._scared_image = self._normal_image
+		self._evil_image = level.sprites[level.EVIL_MONSTER]
 
-		self._image = self._normal__image
+		self._image = self._normal_image
 		self._rect = self._image.get_rect()
 		self._rect.center = centerPoint
 		self._original_rect = pygame.Rect(self._rect)
@@ -71,18 +71,18 @@ class Monster(pygame.sprite.Sprite):
 			self._moveCount = 0
 
 	def SetScared(self, scared):
-		if self._image is self._evil__image:
+		if self._image is self._evil_image:
 			return
 		else:
 			if self._scared != scared:
 				self._scared = scared
 				if scared:
-					self._image = self._scared__image
+					self._image = self._scared_image
 				else:
-					self._image = self._normal__image
+					self._image = self._normal_image
 
 	def Eaten(self):
 		self._rect = self._original_rect
 		self._scared = False
-		self._image = self._evil__image
+		self._image = self._evil_image
 		config.areMonstersEvil = True
