@@ -39,7 +39,10 @@ class nomMain(object):
 		pygame.mixer.pre_init(44100, -16, 1, 256)
 		pygame.init()
 		pygame.mouse.set_visible(False)
-		pygame.mixer.init()
+		try:
+			pygame.mixer.init()
+		except pygame.error:
+			_moduleLogger.exception("Disabling sound support")
 		self._clock = pygame.time.Clock()
 		DATA_FOLDER = os.path.join(os.path.dirname(__file__), "data")
 		self.level1 = None
@@ -450,6 +453,7 @@ class MyForm(QtGui.QMainWindow):
 		try:
 			nomMain().MainLoop()
 		except:
+			_moduleLogger.exception("Catastrophic failure, quitting")
 			pygame.quit()
 			raise
 
@@ -458,6 +462,7 @@ class MyForm(QtGui.QMainWindow):
 		try:
 			nomMain().MainLoop()
 		except:
+			_moduleLogger.exception("Catastrophic failure, quitting")
 			pygame.quit()
 			raise
 
@@ -466,6 +471,7 @@ class MyForm(QtGui.QMainWindow):
 		try:
 			nomMain().MainLoop()
 		except:
+			_moduleLogger.exception("Catastrophic failure, quitting")
 			pygame.quit()
 			raise
 
@@ -474,6 +480,7 @@ class MyForm(QtGui.QMainWindow):
 		try:
 			nomMain().MainLoop()
 		except:
+			_moduleLogger.exception("Catastrophic failure, quitting")
 			pygame.quit()
 			raise
 
